@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2014-2020 Pytroll developers
+# Copyright (c) 2014-2021 Pytroll developers
 #
 # Author(s):
 #
@@ -28,136 +28,13 @@ import logging
 import tempfile
 import numpy as np
 from pyspectral.config import get_config
+from pyspectral.bandnames import BANDNAMES
 
 LOG = logging.getLogger(__name__)
 
 WAVE_LENGTH = 'wavelength'
 WAVE_NUMBER = 'wavenumber'
 
-BANDNAMES = {}
-BANDNAMES['generic'] = {'VIS006': 'VIS0.6',
-                        'VIS008': 'VIS0.8',
-                        'IR_016': 'NIR1.6',
-                        'IR_039': 'IR3.9',
-                        'WV_062': 'IR6.2',
-                        'WV_073': 'IR7.3',
-                        'IR_087': 'IR8.7',
-                        'IR_097': 'IR9.7',
-                        'IR_108': 'IR10.8',
-                        'IR_120': 'IR12.0',
-                        'IR_134': 'IR13.4',
-                        'HRV': 'HRV',
-                        'I01': 'I1',
-                        'I02': 'I2',
-                        'I03': 'I3',
-                        'I04': 'I4',
-                        'I05': 'I5',
-                        'M01': 'M1',
-                        'M02': 'M2',
-                        'M03': 'M3',
-                        'M04': 'M4',
-                        'M05': 'M5',
-                        'M06': 'M6',
-                        'M07': 'M7',
-                        'M08': 'M8',
-                        'M09': 'M9',
-                        'C01': 'ch1',
-                        'C02': 'ch2',
-                        'C03': 'ch3',
-                        'C04': 'ch4',
-                        'C05': 'ch5',
-                        'C06': 'ch6',
-                        'C07': 'ch7',
-                        'C08': 'ch8',
-                        'C09': 'ch9',
-                        'C10': 'ch10',
-                        'C11': 'ch11',
-                        'C12': 'ch12',
-                        'C13': 'ch13',
-                        'C14': 'ch14',
-                        'C15': 'ch15',
-                        'C16': 'ch16',
-                        }
-# handle arbitrary channel numbers
-for chan_num in range(1, 37):
-    BANDNAMES['generic'][str(chan_num)] = 'ch{:d}'.format(chan_num)
-
-# MODIS RSR files were made before 'chX' became standard in pyspectral
-BANDNAMES['modis'] = {str(chan_num): str(chan_num) for chan_num in range(1, 37)}
-
-BANDNAMES['avhrr-3'] = {'1': 'ch1',
-                        '2': 'ch2',
-                        '3b': 'ch3b',
-                        '3a': 'ch3a',
-                        '4': 'ch4',
-                        '5': 'ch5'}
-
-BANDNAMES['ahi'] = {'B01': 'ch1',
-                    'B02': 'ch2',
-                    'B03': 'ch3',
-                    'B04': 'ch4',
-                    'B05': 'ch5',
-                    'B06': 'ch6',
-                    'B07': 'ch7',
-                    'B08': 'ch8',
-                    'B09': 'ch9',
-                    'B10': 'ch10',
-                    'B11': 'ch11',
-                    'B12': 'ch12',
-                    'B13': 'ch13',
-                    'B14': 'ch14',
-                    'B15': 'ch15',
-                    'B16': 'ch16'
-                    }
-
-BANDNAMES['ami'] = {'VI004': 'ch1',
-                    'VI005': 'ch2',
-                    'VI006': 'ch3',
-                    'VI008': 'ch4',
-                    'NR013': 'ch5',
-                    'NR016': 'ch6',
-                    'SW038': 'ch7',
-                    'WV063': 'ch8',
-                    'WV069': 'ch9',
-                    'WV073': 'ch10',
-                    'IR087': 'ch11',
-                    'IR096': 'ch12',
-                    'IR105': 'ch13',
-                    'IR112': 'ch14',
-                    'IR123': 'ch15',
-                    'IR133': 'ch16'
-                    }
-
-BANDNAMES['fci'] = {'vis_04': 'ch1',
-                    'vis_05': 'ch2',
-                    'vis_06': 'ch3',
-                    'vis_08': 'ch4',
-                    'vis_09': 'ch5',
-                    'nir_13': 'ch6',
-                    'nir_16': 'ch7',
-                    'nir_22': 'ch8',
-                    'ir_38': 'ch9',
-                    'wv_63': 'ch10',
-                    'wv_73': 'ch11',
-                    'ir_87': 'ch12',
-                    'ir_97': 'ch13',
-                    'ir_105': 'ch14',
-                    'ir_123': 'ch15',
-                    'ir_133': 'ch16'
-                    }
-
-BANDNAMES['slstr'] = {'S1': 'ch1',
-                      'S2': 'ch2',
-                      'S3': 'ch3',
-                      'S4': 'ch4',
-                      'S5': 'ch5',
-                      'S6': 'ch6',
-                      'S7': 'ch7',
-                      'S8': 'ch8',
-                      'S9': 'ch9',
-                      'F1': 'ch7',
-                      'F2': 'ch8',
-                      }
 
 INSTRUMENTS = {'NOAA-19': 'avhrr/3',
                'NOAA-18': 'avhrr/3',
@@ -193,11 +70,10 @@ INSTRUMENTS = {'NOAA-19': 'avhrr/3',
                'MTG-I1': 'fci'
                }
 
-
-HTTP_PYSPECTRAL_RSR = "https://zenodo.org/record/4305549/files/pyspectral_rsr_data.tgz"
+HTTP_PYSPECTRAL_RSR = "https://zenodo.org/record/5797957/files/pyspectral_rsr_data.tgz"
 
 RSR_DATA_VERSION_FILENAME = "PYSPECTRAL_RSR_VERSION"
-RSR_DATA_VERSION = "v1.0.16"
+RSR_DATA_VERSION = "v1.0.17"
 
 ATM_CORRECTION_LUT_VERSION = {}
 ATM_CORRECTION_LUT_VERSION['antarctic_aerosol'] = {'version': 'v1.0.1',
@@ -209,7 +85,7 @@ ATM_CORRECTION_LUT_VERSION['continental_clean_aerosol'] = {'version': 'v1.0.1',
 ATM_CORRECTION_LUT_VERSION['continental_polluted_aerosol'] = {'version': 'v1.0.1',
                                                               'filename': 'PYSPECTRAL_ATM_CORR_LUT_CPA'}
 ATM_CORRECTION_LUT_VERSION['desert_aerosol'] = {'version': 'v1.0.1',
-                                                           'filename': 'PYSPECTRAL_ATM_CORR_LUT_DA'}
+                                                'filename': 'PYSPECTRAL_ATM_CORR_LUT_DA'}
 ATM_CORRECTION_LUT_VERSION['marine_clean_aerosol'] = {'version': 'v1.0.1',
                                                       'filename': 'PYSPECTRAL_ATM_CORR_LUT_MCA'}
 ATM_CORRECTION_LUT_VERSION['marine_polluted_aerosol'] = {'version': 'v1.0.1',
@@ -223,7 +99,6 @@ ATM_CORRECTION_LUT_VERSION['urban_aerosol'] = {'version': 'v1.0.1',
 ATM_CORRECTION_LUT_VERSION['rayleigh_only'] = {'version': 'v1.0.1',
                                                'filename': 'PYSPECTRAL_ATM_CORR_LUT_RO'}
 
-
 AEROSOL_TYPES = ['antarctic_aerosol', 'continental_average_aerosol',
                  'continental_clean_aerosol', 'continental_polluted_aerosol',
                  'desert_aerosol', 'marine_clean_aerosol',
@@ -234,7 +109,6 @@ ATMOSPHERES = {'subarctic summer': 4, 'subarctic winter': 5,
                'midlatitude summer': 6, 'midlatitude winter': 7,
                'tropical': 8, 'us-standard': 9}
 
-
 HTTPS_RAYLEIGH_LUTS = {}
 URL_PREFIX = "https://zenodo.org/record/1288441/files/pyspectral_atm_correction_luts"
 for atype in AEROSOL_TYPES:
@@ -242,7 +116,6 @@ for atype in AEROSOL_TYPES:
     url = "{prefix}_{name}.tgz".format(prefix=URL_PREFIX, name=name)
     HTTPS_RAYLEIGH_LUTS[atype] = url
 
-
 CONF = get_config()
 LOCAL_RSR_DIR = CONF.get('rsr_dir')
 LOCAL_RAYLEIGH_DIR = CONF.get('rayleigh_dir')
@@ -470,7 +343,7 @@ def download_luts(**kwargs):
     else:
         aerosol_types = HTTPS_RAYLEIGH_LUTS.keys()
 
-    chunk_size = 1024*1024  # 1 MB
+    chunk_size = 1024 * 1024  # 1 MB
 
     for subname in aerosol_types:
 
@@ -582,8 +455,10 @@ def get_wave_range(in_chan, threshold=0.15):
 
 def convert2str(value):
     """Convert a value to string.
+
     Args:
         value: Either a str, bytes or 1-element numpy array
+
     """
     value = bytes2string(value)
     return np2str(value)
@@ -591,11 +466,13 @@ def convert2str(value):
 
 def np2str(value):
     """Convert an `numpy.string_` to str.
+
     Args:
         value (ndarray): scalar or 1-element numpy array to convert
     Raises:
         ValueError: if value is array larger than 1-element or it is not of
                     type `numpy.string_` or it is not a numpy array
+
     """
     if isinstance(value, str):
         return value
